@@ -73,6 +73,7 @@ class InfoWidget(WidgetABC):
 
     def del_info_id(self):
         self.fw.del_info_id()
+        self.info_id = None
 
     def get_picked_frame_labels_for_recog_len(self):
         return len(self.picked_frame_labels_for_recog)
@@ -266,13 +267,9 @@ class InfoWidget(WidgetABC):
         return self.fw.get_action()
 
     def get_info_id(self):
-        if not self.info_id:
-            self.info_id = self.fw.get_info_id()
+        self.info_id = self.fw.get_info_id()
         return self.info_id
 
-    def del_info_id(self):
-        self.fw.del_info_id()
-
     def set_info_id(self, _id):
         self.fw.set_info_id(_id=_id)
         self.info_id = _id
@@ -559,6 +556,7 @@ class InfoWidget(WidgetABC):
         self.del_info_id()
         self.del_picked_frames_for_recog()
         self.del_picked_frames()
+        self.del_saved_frames()
         self.clear_info_widget_area_content()
 
     def update_widgets_by_info_id(self, info_id=None):
@@ -707,9 +705,12 @@ class InfoWidget(WidgetABC):
         self.del_saved_info_by_info_id()
         pass
 
+    def fw_play_button_command(self):
+        self.fw.play_button_command()
+
     def add_button_command(self):
         self.set_adding_status()
-        self.fw.play_button_command()
+        self.fw_play_button_command()
         pass
 
     def set_widgets(self):
